
/* Chrysalide - Outil d'analyse de fichiers binaires
 * loaded.h - prototypes pour l'intégration des contenus chargés
 *
 * Copyright (C) 2017 Cyrille Bagard
 *
 *  This file is part of Chrysalide.
 *
 *  Chrysalide is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Chrysalide is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifndef _ANALYSIS_LOADED_H
#define _ANALYSIS_LOADED_H


#include <glib-object.h>
#include <stdbool.h>
#include <gtk/gtk.h>


#include "../gtkext/gtkdockstation.h"



/* ---------------------- GESTION SOUS FORME DE CONTENU CHARGE ---------------------- */


#define G_TYPE_LOADED_CONTENT             (g_loaded_content_get_type())
#define G_LOADED_CONTENT(obj)             (G_TYPE_CHECK_INSTANCE_CAST((obj), G_TYPE_LOADED_CONTENT, GLoadedContent))
#define G_LOADED_CONTENT_CLASS(vtable)    (G_TYPE_CHECK_CLASS_CAST((vtable), G_TYPE_LOADED_CONTENT, GLoadedContentIface))
#define G_IS_LOADED_CONTENT(obj)          (G_TYPE_CHECK_INSTANCE_TYPE((obj), G_TYPE_LOADED_CONTENT))
#define G_IS_LOADED_CONTENT_CLASS(vtable) (G_TYPE_CHECK_CLASS_TYPE((vtable), G_TYPE_LOADED_CONTENT))
#define G_LOADED_CONTENT_GET_IFACE(inst)  (G_TYPE_INSTANCE_GET_INTERFACE((inst), G_TYPE_LOADED_CONTENT, GLoadedContentIface))


/* Accès à un contenu binaire quelconque (coquille vide) */
typedef struct _GLoadedContent GLoadedContent;

/* Accès à un contenu binaire quelconque (interface) */
typedef struct _GLoadedContentIface GLoadedContentIface;


/* Détermine le type d'une interface pour l'intégration de contenu chargé. */
GType g_loaded_content_get_type(void) G_GNUC_CONST;

/* Fournit le désignation associée à l'élément chargé. */
const char *g_loaded_content_describe(const GLoadedContent *, bool);

/* Détermine le nombre de vues disponibles pour un contenu. */
unsigned int g_loaded_content_count_views(const GLoadedContent *);

/* Met en place la vue demandée pour un contenu chargé. */
GtkWidget *g_loaded_content_build_view(GLoadedContent *, unsigned int);

/* Retrouve l'indice correspondant à la vue donnée d'un contenu. */
unsigned int g_loaded_content_get_view_index(GLoadedContent *, GtkWidget *);

/* Fournit toutes les options d'affichage pour un contenu. */
bool * const g_loaded_content_get_all_display_options(const GLoadedContent *, unsigned int);

/* Définit une option d'affichage pour un contenu chargé. */
void g_loaded_content_set_display_option(GLoadedContent *, unsigned int, unsigned int, bool);



/* ----------------------- VUES ET BASCULEMENT ENTRE LES VUES ----------------------- */


/* Fournit la station d'accueil d'un panneau d'affichage. */
GtkDockStation *get_dock_station_for_view_panel(GtkWidget *);

/* Fournit le support défilant d'un panneau d'affichage. */
GtkWidget *get_scroll_window_for_view_panel(GtkWidget *);

/* Fournit le panneau chargé inclus dans un affichage. */
GtkWidget *get_loaded_panel_from_built_view(GtkWidget *);



#endif  /* _ANALYSIS_LOADED_H */
